==> senior_design_system-2.2.16.tar.gz: example/lib/pages/signature.example.dart <==
import 'package:flutter/material.dart';

import 'package:senior_design_tokens/senior_design_tokens.dart';
import 'package:senior_design_system/senior_design_system.dart';

import '../widgets/page_wrapper.dart';

class SignatureExample extends StatefulWidget {
  const SignatureExample({
    Key? key,
  }) : super(key: key);

  @override
  State<SignatureExample> createState() => _SignatureExampleState();
}

class _SignatureExampleState extends State<SignatureExample> {
  SignatureData? signature;

  void _callSeniorSignature({
    required BuildContext context,
    SignatureData? signature,
  }) {
    return SeniorSignature(
      emptySignatureText: 'Faça sua assinatura aqui',
      modalClear: SeniorModalDefinitions(
        cancelLabel: 'Cancelar',
        confirmLabel: 'Limpar',
        content: '''Você tem certeza que deseja limpar a assinatura? Ao fazer isso ela será perdida.''',
        title: 'Limpar a assinatura',
      ),
      modalGoBack: SeniorModalDefinitions(
        cancelLabel: 'Cancelar',
        confirmLabel: 'Descartar',
        content: '''Você tem certeza que deseja desistir de salvar a sua assinatura? Ao voltar todo o progresso será 
            perdido.''',
        title: 'Voltar para assinatura',
      ),
      onSaveSignature: (signature) {
        setState(() {
          this.signature = signature;
        });
      },
    ).pickImage(context: context, points: signature?.points);
  }

  @override
  Widget build(BuildContext context) {
    return PageWrapper(
      title: 'Signature',
      child: SingleChildScrollView(
        child: Padding(
          padding: const EdgeInsets.all(SeniorSpacing.big),
          child: Column(
            children: [
              Container(
                width: 500.0,
                height: 200.0,
                decoration: BoxDecoration(
                  color: SeniorColors.secondaryColor100,
                  border: Border.all(
                    color: SeniorColors.neutralColor500,
                    width: 1.0,
                  ),
                ),
                child: signature?.file != null
                    ? Image.file(
                        signature!.file!,
                      )
                    : Center(
                        child: SeniorText.body('Podes me dar um autógrafo?'),
                      ),
              ),
              SeniorButton(
                label: 'Editar assinatura',
                type: SeniorButtonType.ghost,
                disabled: signature == null,
                onPressed: () => _callSeniorSignature(
                    context: context, signature: signature),
              ),
              SeniorButton(
                label: 'Nova assinatura',
                type: SeniorButtonType.ghost,
                onPressed: () => _callSeniorSignature(context: context),
              ),
            ],
          ),
        ),
      ),
    );
  }
}

==> senior_design_system-6.0.0.tar.gz: example/lib/pages/signature.example.dart <==
import 'package:flutter/material.dart';

import 'package:senior_design_tokens/senior_design_tokens.dart';
import 'package:senior_design_system/senior_design_system.dart';

import '../widgets/page_wrapper.dart';

class SignatureExample extends StatefulWidget {
  const SignatureExample({
    Key? key,
  }) : super(key: key);

  @override
  State<SignatureExample> createState() => _SignatureExampleState();
}

class _SignatureExampleState extends State<SignatureExample> {
  SignatureData? signature;

  void _callSeniorSignature({
    required BuildContext context,
    SignatureData? signature,
  }) {
    return SeniorSignature(
      emptySignatureText: 'Faça sua assinatura aqui',
      modalClear: SeniorModalDefinitions(
        cancelLabel: 'Cancelar',
        confirmLabel: 'Limpar',
        content:
            '''Você tem certeza que deseja limpar a assinatura? Ao fazer isso ela será perdida.''',
        title: 'Limpar a assinatura',
      ),
      modalGoBack: SeniorModalDefinitions(
        cancelLabel: 'Cancelar',
        confirmLabel: 'Descartar',
        content:
            '''Você tem certeza que deseja desistir de salvar a sua assinatura? Ao voltar todo o progresso será 
            perdido.''',
        title: 'Voltar para assinatura',
      ),
      onSaveSignature: (signature) {
        setState(() {
          this.signature = signature;
        });
      },
    ).pickImage(context: context, points: signature?.points);
  }

  @override
  Widget build(BuildContext context) {
    return PageWrapper(
      title: 'Signature',
      child: SingleChildScrollView(
        child: Padding(
          padding: const EdgeInsets.all(SeniorSpacing.big),
          child: Column(
            children: [
              Container(
                width: 500.0,
                height: 200.0,
                decoration: BoxDecoration(
                  color: SeniorColors.secondaryColor100,
                  border: Border.all(
                    color: SeniorColors.neutralColor500,
                    width: 1.0,
                  ),
                ),
                child: signature?.file != null
                    ? Image.file(
                        signature!.file!,
                      )
                    : Center(
                        child: SeniorText.body('Podes me dar um autógrafo?'),
                      ),
              ),
              SeniorButton.ghost(
                label: 'Editar assinatura',
                disabled: signature == null,
                onPressed: () => _callSeniorSignature(
                    context: context, signature: signature),
              ),
              SeniorButton.ghost(
                label: 'Nova assinatura',
                onPressed: () => _callSeniorSignature(context: context),
              ),
            ],
          ),
        ),
      ),
    );
  }
}
